Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(703)

Unified Diff: src/interpreter/bytecode-array-builder.h

Issue 2302013002: Store the scope info in catch contexts (Closed)
Patch Set: updates Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/full-codegen/full-codegen.cc ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/interpreter/bytecode-array-builder.h
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h
index 404b3aeea5faea5e48e3da97ecbb97e66d434e63..f20d66882b2e0e0895a45cd6dd6ace70e50712ae 100644
--- a/src/interpreter/bytecode-array-builder.h
+++ b/src/interpreter/bytecode-array-builder.h
@@ -139,10 +139,11 @@ class BytecodeArrayBuilder final : public ZoneObject {
// in the accumulator.
BytecodeArrayBuilder& CreateBlockContext(Handle<ScopeInfo> scope_info);
// Create a new context for a catch block with |exception| and |name| and the
// closure in the accumulator.
BytecodeArrayBuilder& CreateCatchContext(Register exception,
- Handle<String> name);
+ Handle<String> name,
+ Handle<ScopeInfo> scope_info);
// Create a new context with size |slots|.
BytecodeArrayBuilder& CreateFunctionContext(int slots);
« no previous file with comments | « src/full-codegen/full-codegen.cc ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
@@ -139,10 +139,11 @@ class BytecodeArrayBuilder final : public ZoneObject {
// in the accumulator.
BytecodeArrayBuilder& CreateBlockContext(Handle<ScopeInfo> scope_info);
- // Create a new context for a catch block with |exception| and |name| and the
- // closure in the accumulator.
+ // Create a new context for a catch block with |exception|, |name|,
+ // |scope_info|, and the closure in the accumulator.
BytecodeArrayBuilder& CreateCatchContext(Register exception,

Powered by Google App Engine
This is Rietveld 408576698